@@ -6,13 +6,13 @@ import httplib
 import urlparse
 import m3u8
 import shutil
-import tempfile
 
 import crypto
 from futures import ThreadPoolExecutor
 
 from hlsclient.transcode import transcode_playlist
 from hlsclient import helpers
+from hlsclient import atomic
 
 config = helpers.load_config()
 NUM_THREAD_WORKERS = config.getint('hlsclient', 'num_thread_workers')
@@ -153,13 +153,8 @@ def save_m3u8(playlist, m3u8_uri, full_path, new_key=False):
     atomic_dump(playlist, filename)
 
 def atomic_dump(playlist, filename):
-    try:
-        fd, tmp_filename = tempfile.mkstemp(dir=os.path.dirname(filename))
-        os.chmod(tmp_filename, 0644)
+    with atomic.AtomicWriteFile(filename) as tmp_filename:
         playlist.dump(tmp_filename)
-        os.rename(tmp_filename, filename)
-    finally:
-        os.close(fd)
 
 def download_key(playlist, destination_path, new_key):
     if playlist.key:
@@ -188,11 +183,5 @@ def download_to_file(uri, destination_path, current_key=None, new_key=False):
     return False
 
 def atomic_write(content, filename):
-    try:
-        fd, tmp_filename = tempfile.mkstemp(dir=os.path.dirname(filename))
-        os.chmod(tmp_filename, 0644)
-        with open(tmp_filename, 'wb') as f:
-            shutil.copyfileobj(content, f)
-        os.rename(tmp_filename, filename)
-    finally:
-        os.close(fd)
+    with atomic.AtomicWriteFileObj(filename) as f:
+        shutil.copyfileobj(content, f)
